# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Tasks

* [`resolve_reference`](#resolve_reference): Return a GitHub organization's repositories as local inventory targets

### Plans

* [`github_inventory::clone_git_repos`](#github_inventoryclone_git_repos): Clone all repos into a local directory
* [`github_inventory::count`](#github_inventorycount): Example plan, prints number of Targets from inventory
* [`github_inventory::latest_semver_tags`](#github_inventorylatest_semver_tags): Report the highest SemVer tag for each repo (that has SemVer tags)
* [`github_inventory::required_checks`](#github_inventoryrequired_checks): List and/or set which PR checks are required on each repo
* [`github_inventory::workflows`](#github_inventoryworkflows): Return repos with GitHub Actions workflows

## Tasks

### <a name="resolve_reference"></a>`resolve_reference`

Return a GitHub organization's repositories as local inventory targets

**Supports noop?** false

#### Parameters

##### `org`

Data type: `String[1]`

GitHub org name (or user login) with repos

##### `github_api_token`

Data type: `Optional[String[1]]`

Optional GitHub personal OAuth token, which may be useful to avoid the GitHub API's unauthenticated rate limits

##### `archived_repos`

Data type: `Boolean`

When true, includes archived repositories in results.

##### `private_repos`

Data type: `Boolean`

When true, includes private repositories in results.

##### `allow_list`

Data type: `Optional[Array[String[1]]]`

repo names/patterns to include in inventory, drops all other repos

##### `block_list`

Data type: `Optional[Array[String[1]]]`

repo names/patterns to reject from inventory (can reject targets in allow_list)

##### `transport_type`

Data type: `String[1]`

Bolt Transport type of repository Targets

##### `extra_gem_path`

Data type: `Optional[String[1]]`

Additional GEM_PATH path for ruby gems (to find `octokit`)

## Plans

### <a name="github_inventoryclone_git_repos"></a>`github_inventory::clone_git_repos`

Clone all repos into a local directory

#### Parameters

The following parameters are available in the `github_inventory::clone_git_repos` plan:

* [`targets`](#targets)
* [`target_dir`](#target_dir)

##### <a name="targets"></a>`targets`

Data type: `TargetSpec`

Name of `github_inventory` Targets (or inventory group)

Default value: `'github_repos'`

##### <a name="target_dir"></a>`target_dir`

Data type: `Stdlib::Absolutepath`

Local directory to clone repos into

Default value: `"${system::env('PWD')}/_repos"`

### <a name="github_inventorycount"></a>`github_inventory::count`

Example plan, prints number of Targets from inventory

#### Parameters

The following parameters are available in the `github_inventory::count` plan:

* [`targets`](#targets)

##### <a name="targets"></a>`targets`

Data type: `TargetSpec`

Name of `github_inventory` Targets (or inventory group)

Default value: `'github_repos'`

### <a name="github_inventorylatest_semver_tags"></a>`github_inventory::latest_semver_tags`

Report the highest SemVer tag for each repo (that has SemVer tags)

* **Note** ONLY reports repos with SemVer tags (ignores `/^v/` and `/-d$/`)

#### Parameters

The following parameters are available in the `github_inventory::latest_semver_tags` plan:

* [`targets`](#targets)
* [`github_api_token`](#github_api_token)

##### <a name="targets"></a>`targets`

Data type: `TargetSpec`

Name of `github_inventory` Targets (or inventory group)

Default value: `'github_repos'`

##### <a name="github_api_token"></a>`github_api_token`

Data type: `Sensitive[String[1]]`

GitHub API token.  Doesn't require any scope for public repos.

Default value: `(system::env('GITHUB_API_TOKEN'))`

### <a name="github_inventoryrequired_checks"></a>`github_inventory::required_checks`

List and/or set which PR checks are required on each repo

#### Parameters

The following parameters are available in the `github_inventory::required_checks` plan:

* [`targets`](#targets)
* [`github_api_token`](#github_api_token)
* [`checks`](#checks)

##### <a name="targets"></a>`targets`

Data type: `TargetSpec`

Name of `github_inventory` Targets (or inventory group)

Default value: `'github_repos'`

##### <a name="github_api_token"></a>`github_api_token`

Data type: `Sensitive[String[1]]`

GitHub API token.  Needs `repo` scope to see or set checks.

Default value: `(system::env('GITHUB_API_TOKEN'))`

##### <a name="checks"></a>`checks`

Data type: `Optional[String[1]]`

Optional comma-delimited list of required PR Checks to set on all repos
If defined, this will overwrite ALL repos' required PR checks

Default value: ``undef``

### <a name="github_inventoryworkflows"></a>`github_inventory::workflows`

Return repos with GitHub Actions workflows

#### Parameters

The following parameters are available in the `github_inventory::workflows` plan:

* [`targets`](#targets)
* [`github_api_token`](#github_api_token)

##### <a name="targets"></a>`targets`

Data type: `TargetSpec`

By default: `github_repos` group from inventory

Default value: `'github_repos'`

##### <a name="github_api_token"></a>`github_api_token`

Data type: `Sensitive[String[1]]`

GitHub API token.  Doesn't require any scope for public repos.

Default value: `(system::env('GITHUB_API_TOKEN'))`

